using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IQueueApi
    {
        /// <summary>
        /// Delete requests of a customer Delete requests of a customer
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <returns></returns>
        void DeleteQueueByCustomerId (string customerid);
        /// <summary>
        /// Delete requests of a company Delete requests of a company
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns></returns>
        void DeleteQueueBycompanyId (string companyid);
        /// <summary>
        /// Get a customerâ€™s queue Get a customerâ€™s queue
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;Queue&gt;</returns>
        List<Queue> GetQueueBycompanyId (string companyid);
        /// <summary>
        /// Get a customerâ€™s queue Get a customerâ€™s queue
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <returns>List&lt;Queue&gt;</returns>
        List<Queue> GetSingleCustomerQueue (string customerid);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class QueueApi : IQueueApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="QueueApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public QueueApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="QueueApi"/> class.
        /// </summary>
        /// <returns></returns>
        public QueueApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Delete requests of a customer Delete requests of a customer
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <returns></returns>            
        public void DeleteQueueByCustomerId (string customerid)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling DeleteQueueByCustomerId");
            
    
            var path = "/deleteQueueByCustomerId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (customerid != null) formParams.Add("customerid", ApiClient.ParameterToString(customerid)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.DELETE, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling DeleteQueueByCustomerId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling DeleteQueueByCustomerId: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Delete requests of a company Delete requests of a company
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns></returns>            
        public void DeleteQueueBycompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling DeleteQueueBycompanyId");
            
    
            var path = "/deleteQueueBycompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (companyid != null) formParams.Add("companyid", ApiClient.ParameterToString(companyid)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.DELETE, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling DeleteQueueBycompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling DeleteQueueBycompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Get a customerâ€™s queue Get a customerâ€™s queue
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;Queue&gt;</returns>            
        public List<Queue> GetQueueBycompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetQueueBycompanyId");
            
    
            var path = "/getQueueBycompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetQueueBycompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetQueueBycompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Queue>) ApiClient.Deserialize(response.Content, typeof(List<Queue>), response.Headers);
        }
    
        /// <summary>
        /// Get a customerâ€™s queue Get a customerâ€™s queue
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <returns>List&lt;Queue&gt;</returns>            
        public List<Queue> GetSingleCustomerQueue (string customerid)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling GetSingleCustomerQueue");
            
    
            var path = "/getQueueByCustomerId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (customerid != null) queryParams.Add("customerid", ApiClient.ParameterToString(customerid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSingleCustomerQueue: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetSingleCustomerQueue: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<Queue>) ApiClient.Deserialize(response.Content, typeof(List<Queue>), response.Headers);
        }
    
    }
}
