using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IRescheduleApi
    {
        /// <summary>
        /// Reschedule Customer (Automatic) Reschedule Customer (Automatic) 
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <returns></returns>
        void RescheduleCustomerAutomatic (string customerid, string language);
        /// <summary>
        /// Reschedule Customer (Send right away) Reschedule Customer (Send right away) 
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <returns></returns>
        void RescheduleCustomerImmediate (string customerid, string language);
        /// <summary>
        /// Reschedule Customer (Manual Schedule) Reschedule Customer (Manual Schedule) 
        /// </summary>
        /// <param name="customerid">Customer ID</param>
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param>
        /// <param name="scheduledate">Schedule date (yyyy/mm/dd) </param>
        /// <param name="scheduletime">Schedule time (HH:MM 24 hours format) </param>
        /// <param name="emailnumber">Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param>
        /// <param name="smsnumber">Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param>
        /// <returns></returns>
        void RescheduleManualOneReviewRequest (string customerid, string language, string scheduledate, string scheduletime, string emailnumber, string smsnumber);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class RescheduleApi : IRescheduleApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="RescheduleApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public RescheduleApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="RescheduleApi"/> class.
        /// </summary>
        /// <returns></returns>
        public RescheduleApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Reschedule Customer (Automatic) Reschedule Customer (Automatic) 
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <returns></returns>            
        public void RescheduleCustomerAutomatic (string customerid, string language)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling RescheduleCustomerAutomatic");
            
            // verify the required parameter 'language' is set
            if (language == null) throw new ApiException(400, "Missing required parameter 'language' when calling RescheduleCustomerAutomatic");
            
    
            var path = "/rescheduleCustomerAutomatic";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (customerid != null) formParams.Add("customerid", ApiClient.ParameterToString(customerid)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling RescheduleCustomerAutomatic: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling RescheduleCustomerAutomatic: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Reschedule Customer (Send right away) Reschedule Customer (Send right away) 
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <returns></returns>            
        public void RescheduleCustomerImmediate (string customerid, string language)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling RescheduleCustomerImmediate");
            
            // verify the required parameter 'language' is set
            if (language == null) throw new ApiException(400, "Missing required parameter 'language' when calling RescheduleCustomerImmediate");
            
    
            var path = "/rescheduleCustomerImmediate";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (customerid != null) formParams.Add("customerid", ApiClient.ParameterToString(customerid)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling RescheduleCustomerImmediate: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling RescheduleCustomerImmediate: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
        /// <summary>
        /// Reschedule Customer (Manual Schedule) Reschedule Customer (Manual Schedule) 
        /// </summary>
        /// <param name="customerid">Customer ID</param> 
        /// <param name="language">Customer Language (Language 2 letter ISO code: en, fr, es, it...). For a complete list of supported languages, please check: https://reputationaegis.com/en/features/supported-languages </param> 
        /// <param name="scheduledate">Schedule date (yyyy/mm/dd) </param> 
        /// <param name="scheduletime">Schedule time (HH:MM 24 hours format) </param> 
        /// <param name="emailnumber">Set which Email Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param> 
        /// <param name="smsnumber">Set which SMS Feedback / Requests will be sent (Allowed values: \&quot;1\&quot;, \&quot;2\&quot;, \&quot;3\&quot;) </param> 
        /// <returns></returns>            
        public void RescheduleManualOneReviewRequest (string customerid, string language, string scheduledate, string scheduletime, string emailnumber, string smsnumber)
        {
            
            // verify the required parameter 'customerid' is set
            if (customerid == null) throw new ApiException(400, "Missing required parameter 'customerid' when calling RescheduleManualOneReviewRequest");
            
            // verify the required parameter 'language' is set
            if (language == null) throw new ApiException(400, "Missing required parameter 'language' when calling RescheduleManualOneReviewRequest");
            
            // verify the required parameter 'scheduledate' is set
            if (scheduledate == null) throw new ApiException(400, "Missing required parameter 'scheduledate' when calling RescheduleManualOneReviewRequest");
            
            // verify the required parameter 'scheduletime' is set
            if (scheduletime == null) throw new ApiException(400, "Missing required parameter 'scheduletime' when calling RescheduleManualOneReviewRequest");
            
            // verify the required parameter 'emailnumber' is set
            if (emailnumber == null) throw new ApiException(400, "Missing required parameter 'emailnumber' when calling RescheduleManualOneReviewRequest");
            
            // verify the required parameter 'smsnumber' is set
            if (smsnumber == null) throw new ApiException(400, "Missing required parameter 'smsnumber' when calling RescheduleManualOneReviewRequest");
            
    
            var path = "/rescheduleManualOneReviewRequest";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
                                    if (customerid != null) formParams.Add("customerid", ApiClient.ParameterToString(customerid)); // form parameter
if (language != null) formParams.Add("language", ApiClient.ParameterToString(language)); // form parameter
if (scheduledate != null) formParams.Add("scheduledate", ApiClient.ParameterToString(scheduledate)); // form parameter
if (scheduletime != null) formParams.Add("scheduletime", ApiClient.ParameterToString(scheduletime)); // form parameter
if (emailnumber != null) formParams.Add("emailnumber", ApiClient.ParameterToString(emailnumber)); // form parameter
if (smsnumber != null) formParams.Add("smsnumber", ApiClient.ParameterToString(smsnumber)); // form parameter
                
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.POST, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling RescheduleManualOneReviewRequest: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling RescheduleManualOneReviewRequest: " + response.ErrorMessage, response.ErrorMessage);
    
            return;
        }
    
    }
}
