using System;
using System.Collections.Generic;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public interface IReviewsStatsApi
    {
        /// <summary>
        /// Get total reviews received for each review site Get total reviews received for each review site
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <param name="lastHowManyDays">Last how many days</param>
        /// <returns>List&lt;ReviewSitesReviewCount&gt;</returns>
        List<ReviewSitesReviewCount> GetNumberOfReviewsPostedInLastDaysByCompanyId (string companyid, string lastHowManyDays);
        /// <summary>
        /// Get for ALL Review Sites the number of 5-star Feedback / Reviews needed to achieve a 5-star Customer Experience  This API call returns for each Review Site of a Company / Location / Feedback Page, the total number of 5-star Feedback / Reviews that the Company / Location needs, to achieve a 5-star Customer Experience. (NOTE: Most Review Sites display a 5-star image when the Overall Rating of a Company / Location is above 4.51. We decided to work as they do and we display a 5-star image for any Overall Rating above 4.51). URL: https://reputationcrm.com/reputation-control    Please refer this image for more information   https://reputationcrm.com/api/repcrm-api-img/NumberOfReviewsRequiredToAchieve5Star.jpg 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;ReviewSitesReviewCount&gt;</returns>
        List<ReviewSitesReviewCount> GetNumberOfReviewsRequiredToAchieve5StarByCompanyId (string companyid);
        /// <summary>
        /// Get The Overall Rating and Total Review Count of a Company / Location for platform collected reviews   Get The Overall Rating and Total Review Count of a Company / Location for platform collected reviews. The number (from 1.00 to 5.00) includes only platform collected reviews.
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;OverallRatingAndReviewCount&gt;</returns>
        List<OverallRatingAndReviewCount> GetOverallRatingAndReviewCountForPlatformReviewsByCompanyId (string companyid);
        /// <summary>
        /// Get overall rating for each review site Get overall rating for each review site
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;ReviewSitesRating&gt;</returns>
        List<ReviewSitesRating> GetOverallRatingForEachReviewSiteByCompanyId (string companyid);
        /// <summary>
        /// Get The Overall Rating of a Company / Location / Feedback Page  This API call returns the Overall Rating of a Company / Location / Feedback Page. The number (from 1.00 to 5.00) includes all Feedback / Reviews of a Company / Location / Feedback Page. URL: https://reputationcrm.com/reputation-control    Please refer https://reputationcrm.com/api/repcrm-api-img/OverallCompanyRating.jpg for more information 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;OverallCompanyRating&gt;</returns>
        List<OverallCompanyRating> GetOverallRatingOfCompanyByCompanyId (string companyid);
        /// <summary>
        /// Get the Overall Reputation Increase / Decrease of ALL Review Sites  This API call returns for each Review Site of a Company / Location / Feedback Page, the Overall Reputation Increase / Decrease of the last 30 days compared to the previous month (31-60 days). 0 means no change: most likely, no new Feedback / Reviews were posted in the past 60 days, or the same number of Feedback / Reviews were posted in the last 30 days compared to the last 31-60 days period. A negative percentage means that the Overall Reputation has suffered. Finally, a positive percentage means an improvement in the Overall Reputation of the Company / Location / Feedback Page. URL: https://reputationcrm.com/reputation-control     Please refer https://reputationcrm.com/api/repcrm-api-img/ReputationChangeInTheLastMonth.jpg for more information 
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;ReviewSitesReputationChange&gt;</returns>
        List<ReviewSitesReputationChange> GetOverallReputationChangeOfAllReviewSitesByCompanyId (string companyid);
        /// <summary>
        /// Get total reviews received for each review site Get total reviews received for each review site
        /// </summary>
        /// <param name="companyid">Company ID</param>
        /// <returns>List&lt;ReviewSitesReviewCount&gt;</returns>
        List<ReviewSitesReviewCount> GetTotalReviewsReceivedForEachReviewSiteByCompanyId (string companyid);
    }
  
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
    public class ReviewsStatsApi : IReviewsStatsApi
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ReviewsStatsApi"/> class.
        /// </summary>
        /// <param name="apiClient"> an instance of ApiClient (optional)</param>
        /// <returns></returns>
        public ReviewsStatsApi(ApiClient apiClient = null)
        {
            if (apiClient == null) // use the default one in Configuration
                this.ApiClient = Configuration.DefaultApiClient; 
            else
                this.ApiClient = apiClient;
        }
    
        /// <summary>
        /// Initializes a new instance of the <see cref="ReviewsStatsApi"/> class.
        /// </summary>
        /// <returns></returns>
        public ReviewsStatsApi(String basePath)
        {
            this.ApiClient = new ApiClient(basePath);
        }
    
        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public void SetBasePath(String basePath)
        {
            this.ApiClient.BasePath = basePath;
        }
    
        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <param name="basePath">The base path</param>
        /// <value>The base path</value>
        public String GetBasePath(String basePath)
        {
            return this.ApiClient.BasePath;
        }
    
        /// <summary>
        /// Gets or sets the API client.
        /// </summary>
        /// <value>An instance of the ApiClient</value>
        public ApiClient ApiClient {get; set;}
    
        /// <summary>
        /// Get total reviews received for each review site Get total reviews received for each review site
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <param name="lastHowManyDays">Last how many days</param> 
        /// <returns>List&lt;ReviewSitesReviewCount&gt;</returns>            
        public List<ReviewSitesReviewCount> GetNumberOfReviewsPostedInLastDaysByCompanyId (string companyid, string lastHowManyDays)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetNumberOfReviewsPostedInLastDaysByCompanyId");
            
            // verify the required parameter 'lastHowManyDays' is set
            if (lastHowManyDays == null) throw new ApiException(400, "Missing required parameter 'lastHowManyDays' when calling GetNumberOfReviewsPostedInLastDaysByCompanyId");
            
    
            var path = "/getNumberOfReviewsPostedInLastDaysByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
 if (lastHowManyDays != null) queryParams.Add("lastHowManyDays", ApiClient.ParameterToString(lastHowManyDays)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetNumberOfReviewsPostedInLastDaysByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetNumberOfReviewsPostedInLastDaysByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSitesReviewCount>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSitesReviewCount>), response.Headers);
        }
    
        /// <summary>
        /// Get for ALL Review Sites the number of 5-star Feedback / Reviews needed to achieve a 5-star Customer Experience  This API call returns for each Review Site of a Company / Location / Feedback Page, the total number of 5-star Feedback / Reviews that the Company / Location needs, to achieve a 5-star Customer Experience. (NOTE: Most Review Sites display a 5-star image when the Overall Rating of a Company / Location is above 4.51. We decided to work as they do and we display a 5-star image for any Overall Rating above 4.51). URL: https://reputationcrm.com/reputation-control    Please refer this image for more information   https://reputationcrm.com/api/repcrm-api-img/NumberOfReviewsRequiredToAchieve5Star.jpg 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;ReviewSitesReviewCount&gt;</returns>            
        public List<ReviewSitesReviewCount> GetNumberOfReviewsRequiredToAchieve5StarByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetNumberOfReviewsRequiredToAchieve5StarByCompanyId");
            
    
            var path = "/getNumberOfReviewsRequiredToAchieve5StarByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetNumberOfReviewsRequiredToAchieve5StarByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetNumberOfReviewsRequiredToAchieve5StarByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSitesReviewCount>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSitesReviewCount>), response.Headers);
        }
    
        /// <summary>
        /// Get The Overall Rating and Total Review Count of a Company / Location for platform collected reviews   Get The Overall Rating and Total Review Count of a Company / Location for platform collected reviews. The number (from 1.00 to 5.00) includes only platform collected reviews.
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;OverallRatingAndReviewCount&gt;</returns>            
        public List<OverallRatingAndReviewCount> GetOverallRatingAndReviewCountForPlatformReviewsByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetOverallRatingAndReviewCountForPlatformReviewsByCompanyId");
            
    
            var path = "/getOverallRatingAndReviewCountForPlatformReviewsByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallRatingAndReviewCountForPlatformReviewsByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallRatingAndReviewCountForPlatformReviewsByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<OverallRatingAndReviewCount>) ApiClient.Deserialize(response.Content, typeof(List<OverallRatingAndReviewCount>), response.Headers);
        }
    
        /// <summary>
        /// Get overall rating for each review site Get overall rating for each review site
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;ReviewSitesRating&gt;</returns>            
        public List<ReviewSitesRating> GetOverallRatingForEachReviewSiteByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetOverallRatingForEachReviewSiteByCompanyId");
            
    
            var path = "/getOverallRatingForEachReviewSiteByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallRatingForEachReviewSiteByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallRatingForEachReviewSiteByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSitesRating>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSitesRating>), response.Headers);
        }
    
        /// <summary>
        /// Get The Overall Rating of a Company / Location / Feedback Page  This API call returns the Overall Rating of a Company / Location / Feedback Page. The number (from 1.00 to 5.00) includes all Feedback / Reviews of a Company / Location / Feedback Page. URL: https://reputationcrm.com/reputation-control    Please refer https://reputationcrm.com/api/repcrm-api-img/OverallCompanyRating.jpg for more information 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;OverallCompanyRating&gt;</returns>            
        public List<OverallCompanyRating> GetOverallRatingOfCompanyByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetOverallRatingOfCompanyByCompanyId");
            
    
            var path = "/getOverallRatingOfCompanyByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallRatingOfCompanyByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallRatingOfCompanyByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<OverallCompanyRating>) ApiClient.Deserialize(response.Content, typeof(List<OverallCompanyRating>), response.Headers);
        }
    
        /// <summary>
        /// Get the Overall Reputation Increase / Decrease of ALL Review Sites  This API call returns for each Review Site of a Company / Location / Feedback Page, the Overall Reputation Increase / Decrease of the last 30 days compared to the previous month (31-60 days). 0 means no change: most likely, no new Feedback / Reviews were posted in the past 60 days, or the same number of Feedback / Reviews were posted in the last 30 days compared to the last 31-60 days period. A negative percentage means that the Overall Reputation has suffered. Finally, a positive percentage means an improvement in the Overall Reputation of the Company / Location / Feedback Page. URL: https://reputationcrm.com/reputation-control     Please refer https://reputationcrm.com/api/repcrm-api-img/ReputationChangeInTheLastMonth.jpg for more information 
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;ReviewSitesReputationChange&gt;</returns>            
        public List<ReviewSitesReputationChange> GetOverallReputationChangeOfAllReviewSitesByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetOverallReputationChangeOfAllReviewSitesByCompanyId");
            
    
            var path = "/getOverallReputationChangeOfAllReviewSitesByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallReputationChangeOfAllReviewSitesByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetOverallReputationChangeOfAllReviewSitesByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSitesReputationChange>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSitesReputationChange>), response.Headers);
        }
    
        /// <summary>
        /// Get total reviews received for each review site Get total reviews received for each review site
        /// </summary>
        /// <param name="companyid">Company ID</param> 
        /// <returns>List&lt;ReviewSitesReviewCount&gt;</returns>            
        public List<ReviewSitesReviewCount> GetTotalReviewsReceivedForEachReviewSiteByCompanyId (string companyid)
        {
            
            // verify the required parameter 'companyid' is set
            if (companyid == null) throw new ApiException(400, "Missing required parameter 'companyid' when calling GetTotalReviewsReceivedForEachReviewSiteByCompanyId");
            
    
            var path = "/getTotalReviewsReceivedForEachReviewSiteByCompanyId";
            path = path.Replace("{format}", "json");
                
            var queryParams = new Dictionary<String, String>();
            var headerParams = new Dictionary<String, String>();
            var formParams = new Dictionary<String, String>();
            var fileParams = new Dictionary<String, FileParameter>();
            String postBody = null;
    
             if (companyid != null) queryParams.Add("companyid", ApiClient.ParameterToString(companyid)); // query parameter
                                        
            // authentication setting, if any
            String[] authSettings = new String[] { "api_key" };
    
            // make the HTTP request
            IRestResponse response = (IRestResponse) ApiClient.CallApi(path, Method.GET, queryParams, postBody, headerParams, formParams, fileParams, authSettings);
    
            if (((int)response.StatusCode) >= 400)
                throw new ApiException ((int)response.StatusCode, "Error calling GetTotalReviewsReceivedForEachReviewSiteByCompanyId: " + response.Content, response.Content);
            else if (((int)response.StatusCode) == 0)
                throw new ApiException ((int)response.StatusCode, "Error calling GetTotalReviewsReceivedForEachReviewSiteByCompanyId: " + response.ErrorMessage, response.ErrorMessage);
    
            return (List<ReviewSitesReviewCount>) ApiClient.Deserialize(response.Content, typeof(List<ReviewSitesReviewCount>), response.Headers);
        }
    
    }
}
